==> green-core-1.70.1.tgz: package/components/radio/radio.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet
} from "../../chunks/chunk.QTSIPXV3.js";
var _handleClick, _handleKeyDown;
import { property, state } from "lit/decorators.js";
import { GdsElement } from "../../gds-element";
import { GdsSelectionFieldLabel } from "../../primitives/selection-controls/selection-field-label.component";
import { gdsCustomElement, html } from "../../scoping";
import { watch } from "../../utils/decorators/watch";
import { styles } from "./radio.styles";
let GdsRadio = class extends GdsElement {
  constructor() {
    super();
    this.label = "";
    this.supportingText = "";
    this.value = "";
    this.checked = false;
    this.disabled = false;
    this.invalid = false;
    this._isFocused = false;
    __privateAdd(this, _handleClick, (e) => {
      if (this.disabled || !this.value || !this.label)
        return;
      e.preventDefault();
      this.checked = true;
      this.focus();
      this.dispatchEvent(new Event("gds-radio-change", { bubbles: true }));
    });
    __privateAdd(this, _handleKeyDown, (e) => {
      if (this.disabled)
        return;
      if (e.key === "Enter" || e.key === " ") {
        e.preventDefault();
        this.checked = true;
        this.dispatchEvent(new Event("gds-radio-change", { bubbles: true }));
      }
    });
    this.addEventListener("keydown", __privateGet(this, _handleKeyDown));
    this.addEventListener("focus", () => this._isFocused = true);
    this.addEventListener("blur", () => this._isFocused = false);
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "radio");
    this._updateAriaState();
    this.addEventListener("click", __privateGet(this, _handleClick));
  }
  _updateAriaState() {
    this.setAttribute("aria-checked", this.checked.toString());
    this.setAttribute("aria-disabled", this.disabled.toString());
    this.setAttribute("tabindex", this.disabled ? "-1" : "0");
    this.toggleAttribute("aria-invalid", this.invalid);
  }
  updated(changedProperties) {
    super.updated(changedProperties);
    if (changedProperties.has("checked") || changedProperties.has("disabled") || changedProperties.has("invalid")) {
      this._updateAriaState();
    }
  }
  _handleDisabledChange() {
    if (this.disabled) {
      this.setAttribute("inert", "");
    } else {
      this.removeAttribute("inert");
    }
  }
  render() {
    return html`
      <gds-selection-field-label
        supporting-text=${this.supportingText}
        label=${this.label}
        type="radio"
      >
        <div class="radio">
          <div class="state"></div>
          <div class="disc"></div>
        </div>
      </gds-selection-field-label>
    `;
  }
};
_handleClick = new WeakMap();
_handleKeyDown = new WeakMap();
GdsRadio.styles = [styles];
__decorateClass([
  property()
], GdsRadio.prototype, "label", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], GdsRadio.prototype, "supportingText", 2);
__decorateClass([
  property()
], GdsRadio.prototype, "value", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsRadio.prototype, "checked", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsRadio.prototype, "disabled", 2);
__decorateClass([
  property({ type: Boolean })
], GdsRadio.prototype, "invalid", 2);
__decorateClass([
  state()
], GdsRadio.prototype, "_isFocused", 2);
__decorateClass([
  watch("disabled")
], GdsRadio.prototype, "_handleDisabledChange", 1);
GdsRadio = __decorateClass([
  gdsCustomElement("gds-radio", { dependsOn: [GdsSelectionFieldLabel] })
], GdsRadio);
export {
  GdsRadio
};

==> green-core-1.71.0.tgz: package/components/radio/radio.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet
} from "../../chunks/chunk.QTSIPXV3.js";
var _handleClick, _handleKeyDown;
import { property, state } from "lit/decorators.js";
import { GdsElement } from "../../gds-element.js";
import { GdsSelectionFieldLabel } from "../../primitives/selection-controls/selection-field-label.component.js";
import { gdsCustomElement, html } from "../../scoping.js";
import { watch } from "../../utils/decorators/watch.js";
import { styles } from "./radio.styles";
let GdsRadio = class extends GdsElement {
  constructor() {
    super();
    this.label = "";
    this.supportingText = "";
    this.value = "";
    this.checked = false;
    this.disabled = false;
    this.invalid = false;
    this._isFocused = false;
    __privateAdd(this, _handleClick, (e) => {
      if (this.disabled || !this.value || !this.label)
        return;
      e.preventDefault();
      this.checked = true;
      this.focus();
      this.dispatchEvent(new Event("gds-radio-change", { bubbles: true }));
    });
    __privateAdd(this, _handleKeyDown, (e) => {
      if (this.disabled)
        return;
      if (e.key === "Enter" || e.key === " ") {
        e.preventDefault();
        this.checked = true;
        this.dispatchEvent(new Event("gds-radio-change", { bubbles: true }));
      }
    });
    this.addEventListener("keydown", __privateGet(this, _handleKeyDown));
    this.addEventListener("focus", () => this._isFocused = true);
    this.addEventListener("blur", () => this._isFocused = false);
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "radio");
    this._updateAriaState();
    this.addEventListener("click", __privateGet(this, _handleClick));
  }
  _updateAriaState() {
    this.setAttribute("aria-checked", this.checked.toString());
    this.setAttribute("aria-disabled", this.disabled.toString());
    this.setAttribute("tabindex", this.disabled ? "-1" : "0");
    this.toggleAttribute("aria-invalid", this.invalid);
  }
  updated(changedProperties) {
    super.updated(changedProperties);
    if (changedProperties.has("checked") || changedProperties.has("disabled") || changedProperties.has("invalid")) {
      this._updateAriaState();
    }
  }
  _handleDisabledChange() {
    if (this.disabled) {
      this.setAttribute("inert", "");
    } else {
      this.removeAttribute("inert");
    }
  }
  render() {
    return html`
      <gds-selection-field-label
        supporting-text=${this.supportingText}
        label=${this.label}
        type="radio"
      >
        <div class="radio">
          <div class="state"></div>
          <div class="disc"></div>
        </div>
      </gds-selection-field-label>
    `;
  }
};
_handleClick = new WeakMap();
_handleKeyDown = new WeakMap();
GdsRadio.styles = [styles];
__decorateClass([
  property()
], GdsRadio.prototype, "label", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], GdsRadio.prototype, "supportingText", 2);
__decorateClass([
  property()
], GdsRadio.prototype, "value", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsRadio.prototype, "checked", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsRadio.prototype, "disabled", 2);
__decorateClass([
  property({ type: Boolean })
], GdsRadio.prototype, "invalid", 2);
__decorateClass([
  state()
], GdsRadio.prototype, "_isFocused", 2);
__decorateClass([
  watch("disabled")
], GdsRadio.prototype, "_handleDisabledChange", 1);
GdsRadio = __decorateClass([
  gdsCustomElement("gds-radio", { dependsOn: [GdsSelectionFieldLabel] })
], GdsRadio);
export {
  GdsRadio
};
